<?php
/**
 * WC Setting Tab
 *
 * Create A Seperate Tab for Configuration
 */
 
 
if ( !defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

if ( !class_exists( 'WC_SMS_Settings' ) ) {
	class WC_SMS_Settings {
		const SETTINGS_NAMESPACE = 'sms_settings';
		
		
		/**
		 * Get the setting fields
		 *
		 * @since  1.0.0
		 * @access private
		 *
		 * @return array $setting_fields
		 */
		private function get_fields() {
			$setting_fields = array(
				'section_title' => array(
					'name' => __( 'HSPSMS', 'woo-hsp-sms' ),
					'type' => 'title',
					'desc' => '',
					'id'   => 'wc_settings_' . self::SETTINGS_NAMESPACE . '_title'
				),
				'hsp_username' => array(
					'name'    => __( 'HSP SMS User Name', 'woo-hsp-sms' ),
					'type'    => 'text',
					'desc'    => __( 'Kindly Enter HSP Username. You can find this from HSP SMS offecial site.', 'woo-hsp-sms' ),
					'id'      => 'wc_settings_' . self::SETTINGS_NAMESPACE . '_hsp_username',
					'default' => '',
				),
				'api_key' => array(
					'name'    => __( 'API Key', 'woo-hsp-sms' ),
					'type'    => 'text',
					'desc'    => __( 'API Key Of your Account', 'woo-hsp-sms' ),
					'id'      => 'wc_settings_' . self::SETTINGS_NAMESPACE . '_api_key',
					'default' => '',
				),
				'sendername_key' => array(
					'name'    => __( 'Sender Name', 'woo-hsp-sms' ),
					'type'    => 'text',
					'desc'    => __( 'Sender Name Of your Account', 'woo-hsp-sms' ),
					'id'      => 'wc_settings_' . self::SETTINGS_NAMESPACE . '_sendername_key',
					'default' => '',
				),
				'smstype' => array(
					'name'    => __( 'SMS Type', 'woo-hsp-sms' ),
					'type'    => 'text',
					'desc'    => __( 'SMS Type', 'woo-hsp-sms' ),
					'id'      => 'wc_settings_' . self::SETTINGS_NAMESPACE . '_smstype',
					'default' => '',
				),
				'order_sms_text' => array(
					'name'    => __( 'Order Message Text', 'woo-hsp-sms' ),
					'type'    => 'textarea',
					'desc'    => __( 'Order Message Text Please user {%ORDER_ID%} for Mentioned Order Number , {%FIRSTNAME%} for First name and {%TOTAL%} for total amount', 'woo-hsp-sms' ),
					'id'      => 'wc_settings_' . self::SETTINGS_NAMESPACE . '_order_sms_text',
					'default' => 'Thank you for your order. Your Order ID is {%ORDER_ID%} . Thank you',
				),
				'section_end'   => array(
					'type' => 'sectionend',
					'id'   => 'wc_settings_' . self::SETTINGS_NAMESPACE . '_section_end'
				)
			);
			return apply_filters( 'wc_settings_tab_' . self::SETTINGS_NAMESPACE, $setting_fields );
		}
		/**
		 * Get an option set in our settings tab
		 *
		 * @param $key
		 *
		 * @since  1.0.0
		 * @access public
		 *
		 * @return String
		 */
		public function get_option( $key ) {
			$fields = $this->get_fields();
			return apply_filters( 'wc_option_' . $key, get_option( 'wc_settings_' . self::SETTINGS_NAMESPACE . '_' . $key, ( ( isset( $fields[$key] ) && isset( $fields[$key]['default'] ) ) ? $fields[$key]['default'] : '' ) ) );
		}
		/**
		 * Setup the WooCommerce settings
		 *
		 * @since  1.0.0
		 * @access public
		 */
		public function setup() {
			add_filter( 'woocommerce_settings_tabs_array', array( $this, 'add_settings_tab' ), 70 );
			add_action( 'woocommerce_settings_tabs_' . self::SETTINGS_NAMESPACE, array( $this, 'tab_content' ) );
			add_action( 'woocommerce_update_options_' . self::SETTINGS_NAMESPACE, array( $this, 'update_settings' ) );
		}
		/**
		 * Add a settings tab to the settings page
		 *
		 * @param array $settings_tabs
		 *
		 * @since  1.0.0
		 * @access public
		 *
		 * @return array
		 */
		public function add_settings_tab( $settings_tabs ) {
			$settings_tabs[self::SETTINGS_NAMESPACE] = __( 'HSP SMS', 'woo-hsp-sms' );
			return $settings_tabs;
		}
		/**
		 * Output the tab content
		 *
		 * @since  1.0.0
		 * @access public
		 *
		 */
		public function tab_content() {
			woocommerce_admin_fields( $this->get_fields() );
		}
		/**
		 * Update the settings
		 *
		 * @since  1.0.0
		 * @access public
		 */
		public function update_settings() {
			woocommerce_update_options( $this->get_fields() );
		}
	}
}
